@@ -85,6 +85,18 @@ void Python2Session::login()
         QObject::connect(m_watch, SIGNAL(created(QString)), SLOT(plotFileChanged(QString)));
     }
 
+    if(!Python2Settings::self()->autorunScripts().isEmpty()){
+        QString autorunScripts = Python2Settings::self()->autorunScripts().join("\n");
+        getPythonCommandOutput(autorunScripts);
+    }
+
+    QString importDefaultModules = "import numpy\n"      \
+                                   "import scipy\n"      \
+                                   "import matplotlib\n" \
+                                   "import pylab";
+
+    evaluateExpression(importDefaultModules, Cantor::Expression::DeleteOnFinish);
+
     listVariables();
 
     emit ready();
